@@ -1,9 +1,11 @@
 from .Equipment import Equipment
 from .MainSystem import MainSystem
 from .Plant import Plant
+from .Organization import Organization
 
 __all__ = [
     'Equipment',
     'MainSystem',
-    'Plant'
+    'Plant',
+    'Organization'
 ]
\ No newline at end of file
