@@ -2,9 +2,10 @@ from .Category import Category
 from .Classification import Classification, ClassificationElement
 from .PropertyDefinition import PropertyDefinition
 from .WorkItem import WorkItemActivity 
-from .Activity import Activity, Input
+from .Activity import Activity, Input, ActivityMediaReference
 from .Deviation import Deviation
 from .Media import Media
+from .MediaReference import MediaReference
 
 
 __all__ = [
@@ -17,5 +18,7 @@ __all__ = [
     'WorkItem',
     'Input',
     'WorkItemActivity',
-    'Media'
+    'Media',
+    'MediaReference',
+    'ActivityMediaReference'
 ]
\ No newline at end of file
