@@ -5,7 +5,7 @@ class Channel(SignalsObject):
     
     def __init__(self):
         super().__init__()
-        self._endpoint = 'channels'
+        self._endpoint = 'Channels'
 
 
     def get_signals(self, from_millis):
